% vGRAPPA decomposition algorithm
% 
% This algorithm decomposes simultaneously acquired multi-voxel 
% data to their respective origin regions. Based on the split-slice GRAPPA code by Steen Moeller, University of Minnesota, USA.
%
% Author: L.T. Riemann (Physikalisch-Technische Bundesanstalt, PTB)
% version 0.1
% Date: 2021/05/08
%
% Please cite as: L.T.Riemann, C.S.Aigner, R.Mekle, S.Schmitter, B.Ittermann, A.Fillmer; 
% "Fourier-based decomposition approach for simultaneous acquisition of\""
% "H spectra from two voxels in vivo at short echo times", Proc. Int. Soc. Magn. Reson. Med. 2021:0071
%

close all;
clear all;
%load the low SNR SB raw data 
sb1.path='v1_lowsnr.dat';
[sb1.mrprot, sb1.mdh, sb1.fid] = rdMeas_TXfct(sb1.path );
tmp = sortMeas_TXfct(sb1.mrprot, sb1.mdh,sb1.fid);
sb1.fidsort = permute(tmp, [1 5 6 2 3 4]);
sb1.freq = fftshift(fftnsh(sb1.fidsort,1,0),1);

sb2.path='v2_lowsnr.dat';
[sb2.mrprot, sb2.mdh, sb2.fid] = rdMeas_TXfct(sb2.path );
tmp = sortMeas_TXfct(sb2.mrprot, sb2.mdh,sb2.fid);
sb2.fidsort = permute(tmp, [1 5 6 2 3 4]);
sb2.freq = fftshift(fftnsh(sb2.fidsort,1,0),1);

%load the MB raw data 
mb.path='mb.dat';

[mb.mrprot, mb.mdh, mb.fid] = rdMeas_TXfct(mb.path );
tmp = sortMeas_TXfct(mb.mrprot, mb.mdh,mb.fid);
tmp2=tmp(:,:,:,:,1:2:end,:)+tmp(:,:,:,:,2:2:end,:); %for on/off scheme SPECIAL
mb.fidsort = permute(tmp2, [1 5 6 2 3 4]);
mb.freq = fftshift(fftnsh(mb.fidsort,1,0),1);

caltmp = cat(4,sb1.freq(:,:,:,:),sb2.freq(:,:,:,:));
cal = caltmp(:,1:2:end,:,:)+caltmp(:,2:2:end,:,:);

% figure;
sb1.mag = (rsos(sb1.freq(:,:),2));
sb2.mag = (rsos(sb2.freq(:,:),2));
%Kernel: 
ws = []; 
%here do the recon:  
[recon,ws2 ] = GRAPPA_MB2aa_asym_kernel_new_blocking(mb.freq,cal, [], 11,2,1,1); %MB data, calibration data, ws, kernelsize kernelsize, 1, 1,)

%recon of SUMSB dataset: 
sumsb.freq = sum(cal,4);

rec1 = recon(:,:,:,1);
rec11= ifft(ifftshift(rec1));
si=size(rec11);
rec11=interp1(rec11,linspace(1,si(1),2*si(1)));
[tt,averages,coils]=size(rec11);
rec11 = reshape(rec11,[tt,1,1,coils,1,1,1,1,1,1,averages]);
save('v1_reco.mat','rec11');
rec2 = recon(:,:,:,2);
rec22=ifft(ifftshift(rec2));
rec22=interp1(rec22,linspace(1,si(1),2*si(1)));
rec22 = reshape(rec22,[tt,1,1,coils,1,1,1,1,1,1,averages]);
save('v2_reco.mat','rec22');
mbreco.mag1 = rsos(rec1(:,:),2);
mbreco.mag2 = rsos(rec2(:,:),2);

inp = cal(:,1:2:end,:,1);
input.mag1 = rsos(inp(:,:),2);
inp = cal(:,1:2:end,:,2);
input.mag2 = rsos(inp(:,:),2);

xaxis = 1:length(input.mag1);
figure;
plot(xaxis,input.mag1, xaxis, mbreco.mag1)

figure;
plot(xaxis,input.mag2, xaxis, mbreco.mag2)

figure;
plot(xaxis,mbreco.mag1, xaxis, mbreco.mag2)
T=table(mbreco.mag1,mbreco.mag2,input.mag1,input.mag2,'VariableNames',{'V1reco','V2reco','V1_orig','V2_orig'});
